=== modified file 'configure.ac'
--- configure.ac	2011-02-13 17:26:39 +0000
+++ configure.ac	2011-02-20 20:47:53 +0000
@@ -72,6 +72,7 @@
 PANDORA_REQUIRE_LIBREADLINE
 PANDORA_REQUIRE_LIBDL
 AC_LANG_POP
+AC_FUNC_STRERROR_R
 
 DRIZZLE_STACK_DIRECTION
 

=== modified file 'drizzled/errmsg_print.cc'
--- drizzled/errmsg_print.cc	2011-02-17 00:14:13 +0000
+++ drizzled/errmsg_print.cc	2011-02-20 20:47:53 +0000
@@ -36,10 +36,19 @@
 
 void sql_perror(const char *message)
 {
+  char *errmsg_ptr;
   char errmsg[STRERROR_MAX];
   errmsg[0]= 0;
+
+#ifdef STRERROR_R_CHAR_P
+  errmsg_ptr= strerror_r(errno, errmsg, sizeof(errmsg));
+#else
   strerror_r(errno, errmsg, sizeof(errmsg));
+  errmsg_ptr= errmsg;
+#endif
+
   errmsg_printf(error::ERROR, "%s: %s\n", message, errmsg);
+
 }
 
 // @todo Cap the size of message.
@@ -52,9 +61,16 @@
 // @todo Cap the size of message/extra.
 void sql_perror(std::string message, const std::string &extra)
 {
+  char *errmsg_ptr;
   char errmsg[STRERROR_MAX];
   errmsg[0]= 0;
+
+#ifdef STRERROR_R_CHAR_P
+  errmsg_ptr= strerror_r(errno, errmsg, sizeof(errmsg));
+#else
   strerror_r(errno, errmsg, sizeof(errmsg));
+  errmsg_ptr= errmsg;
+#endif
 
   if (not extra.empty())
   {

=== modified file 'drizzled/field.cc'
--- drizzled/field.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field.cc	2011-02-20 10:35:17 +0000
@@ -746,26 +746,26 @@
   return 0;
 }
 
-bool Field::is_null(ptrdiff_t row_offset)
+bool Field::is_null(ptrdiff_t row_offset) const
 {
   return null_ptr ?
     (null_ptr[row_offset] & null_bit ? true : false) :
     table->null_row;
 }
 
-bool Field::is_real_null(ptrdiff_t row_offset)
+bool Field::is_real_null(ptrdiff_t row_offset) const
 {
   return null_ptr ? (null_ptr[row_offset] & null_bit ? true : false) : false;
 }
 
-bool Field::is_null_in_record(const unsigned char *record)
+bool Field::is_null_in_record(const unsigned char *record) const
 {
   if (! null_ptr)
     return false;
   return test(record[(uint32_t) (null_ptr -table->getInsertRecord())] & null_bit);
 }
 
-bool Field::is_null_in_record_with_offset(ptrdiff_t with_offset)
+bool Field::is_null_in_record_with_offset(ptrdiff_t with_offset) const
 {
   if (! null_ptr)
     return false;
@@ -784,12 +784,12 @@
     null_ptr[row_offset]&= (unsigned char) ~null_bit;
 }
 
-bool Field::maybe_null(void)
+bool Field::maybe_null(void) const
 {
   return null_ptr != 0 || table->maybe_null;
 }
 
-bool Field::real_maybe_null(void)
+bool Field::real_maybe_null(void) const
 {
   return null_ptr != 0;
 }
@@ -851,7 +851,7 @@
 {
 }
 
-void Field::hash(uint32_t *nr, uint32_t *nr2)
+void Field::hash(uint32_t *nr, uint32_t *nr2) const
 {
   if (is_null())
   {
@@ -943,7 +943,7 @@
   return(result);
 }
 
-type::Decimal *Field::val_decimal(type::Decimal *)
+type::Decimal *Field::val_decimal(type::Decimal *) const
 {
   /* This never have to be called */
   assert(0);
@@ -1012,14 +1012,14 @@
   return copy->length+ store_length;
 }
 
-bool Field::get_date(type::Time &ltime, uint32_t fuzzydate)
+bool Field::get_date(type::Time &ltime, uint32_t fuzzydate) const
 {
   char buff[type::Time::MAX_STRING_LENGTH];
   String tmp(buff,sizeof(buff),&my_charset_bin),*res;
 
   assert(getTable() and getTable()->getSession());
 
-  if (not (res=val_str_internal(&tmp)) or
+  if (not (res= val_str_internal(&tmp)) or
       str_to_datetime_with_warn(getTable()->getSession(),
                                 res->ptr(), res->length(),
                                 &ltime, fuzzydate) <= type::DRIZZLE_TIMESTAMP_ERROR)
@@ -1030,7 +1030,7 @@
   return false;
 }
 
-bool Field::get_time(type::Time &ltime)
+bool Field::get_time(type::Time &ltime) const
 {
   char buff[type::Time::MAX_STRING_LENGTH];
   String tmp(buff,sizeof(buff),&my_charset_bin),*res;
@@ -1253,7 +1253,7 @@
   }
 }
 
-bool Field::isReadSet() 
+bool Field::isReadSet() const 
 { 
   return table->isReadSet(field_index); 
 }

=== modified file 'drizzled/field.h'
--- drizzled/field.h	2011-02-17 00:14:13 +0000
+++ drizzled/field.h	2011-02-20 10:35:17 +0000
@@ -217,10 +217,10 @@
       Needs to be changed if/when we want to support different time formats.
   */
   virtual int store_time(type::Time &ltime, type::timestamp_t t_type);
-  virtual double val_real()=0;
-  virtual int64_t val_int()=0;
-  virtual type::Decimal *val_decimal(type::Decimal *);
-  String *val_str_internal(String *str)
+  virtual double val_real() const=0;
+  virtual int64_t val_int() const =0;
+  virtual type::Decimal *val_decimal(type::Decimal *) const;
+  String *val_str_internal(String *str) const
   {
     return val_str(str, str);
   }
@@ -237,7 +237,7 @@
      an unnecessary free (and later, may be an alloc).
      This trickery is used to decrease a number of malloc calls.
   */
-  virtual String *val_str(String*, String *)=0;
+  virtual String *val_str(String*, String *) const =0;
 
   /*
    str_needs_quotes() returns true if the value returned by val_str() needs
@@ -363,14 +363,14 @@
   // For new field
   virtual uint32_t size_of() const =0;
 
-  bool is_null(ptrdiff_t row_offset= 0);
-  bool is_real_null(ptrdiff_t row_offset= 0);
-  bool is_null_in_record(const unsigned char *record);
-  bool is_null_in_record_with_offset(ptrdiff_t offset);
+  bool is_null(ptrdiff_t row_offset= 0) const;
+  bool is_real_null(ptrdiff_t row_offset= 0) const;
+  bool is_null_in_record(const unsigned char *record) const;
+  bool is_null_in_record_with_offset(ptrdiff_t offset) const;
   void set_null(ptrdiff_t row_offset= 0);
   void set_notnull(ptrdiff_t row_offset= 0);
-  bool maybe_null(void);
-  bool real_maybe_null(void);
+  bool maybe_null(void) const;
+  bool real_maybe_null(void) const;
 
   virtual void make_field(SendField *);
   virtual void sort_string(unsigned char *buff,uint32_t length)=0;
@@ -596,8 +596,8 @@
   }
   void copy_from_tmp(int offset);
   uint32_t fill_cache_field(CacheField *copy);
-  virtual bool get_date(type::Time &ltime,uint32_t fuzzydate);
-  virtual bool get_time(type::Time &ltime);
+  virtual bool get_date(type::Time &ltime,uint32_t fuzzydate) const;
+  virtual bool get_time(type::Time &ltime) const;
   virtual const CHARSET_INFO *charset(void) const { return &my_charset_bin; }
   virtual const CHARSET_INFO *sort_charset(void) const { return charset(); }
   virtual bool has_charset(void) const { return false; }
@@ -738,7 +738,7 @@
   }
 
   /* Hash value */
-  virtual void hash(uint32_t *nr, uint32_t *nr2);
+  virtual void hash(uint32_t *nr, uint32_t *nr2) const;
   friend bool reopen_table(Session *,Table *,bool);
 
   friend class CopyField;
@@ -754,7 +754,7 @@
   friend class Item_sum_max;
   friend class Item_func_group_concat;
 
-  bool isReadSet();
+  bool isReadSet() const;
   bool isWriteSet();
   void setReadSet(bool arg= true);
   void setWriteSet(bool arg= true);

=== modified file 'drizzled/field/blob.cc'
--- drizzled/field/blob.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/blob.cc	2011-02-19 01:04:19 +0000
@@ -90,7 +90,7 @@
 
 
 uint32_t Field_blob::get_length(const unsigned char *pos,
-                                bool low_byte_first)
+                                bool low_byte_first) const
 {
 #ifndef WORDS_BIGENDIAN
   (void)low_byte_first;
@@ -113,14 +113,14 @@
 }
 
 
-uint32_t Field_blob::get_length(uint32_t row_offset)
+uint32_t Field_blob::get_length(uint32_t row_offset) const
 {
   return get_length(ptr+row_offset,
                     getTable()->getShare()->db_low_byte_first);
 }
 
 
-uint32_t Field_blob::get_length(const unsigned char *ptr_arg)
+uint32_t Field_blob::get_length(const unsigned char *ptr_arg) const
 {
   return get_length(ptr_arg, getTable()->getShare()->db_low_byte_first);
 }
@@ -224,7 +224,7 @@
 }
 
 
-double Field_blob::val_real(void)
+double Field_blob::val_real(void) const
 {
   int not_used;
   char *end_not_used, *blob;
@@ -242,7 +242,7 @@
 }
 
 
-int64_t Field_blob::val_int(void)
+int64_t Field_blob::val_int(void) const
 {
   int not_used;
   char *blob;
@@ -252,12 +252,11 @@
   memcpy(&blob,ptr+sizeof(uint32_t),sizeof(char*));
   if (!blob)
     return 0;
-  uint32_t length=get_length(ptr);
+  uint32_t length= get_length(ptr);
   return my_strntoll(charset(),blob,length,10,NULL,&not_used);
 }
 
-String *Field_blob::val_str(String *,
-			    String *val_ptr)
+String *Field_blob::val_str(String *, String *val_ptr) const
 {
   char *blob;
 
@@ -272,7 +271,7 @@
 }
 
 
-type::Decimal *Field_blob::val_decimal(type::Decimal *decimal_value)
+type::Decimal *Field_blob::val_decimal(type::Decimal *decimal_value) const
 {
   const char *blob;
   size_t length;

=== modified file 'drizzled/field/blob.h'
--- drizzled/field/blob.h	2011-02-17 00:14:13 +0000
+++ drizzled/field/blob.h	2011-02-19 01:04:19 +0000
@@ -77,10 +77,10 @@
   int  store(double nr);
   int  store(int64_t nr, bool unsigned_val);
 
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
-  type::Decimal *val_decimal(type::Decimal *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
+  type::Decimal *val_decimal(type::Decimal *) const;
   int cmp_max(const unsigned char *, const unsigned char *, uint32_t max_length);
   int cmp(const unsigned char *a,const unsigned char *b)
     { return cmp_max(a, b, UINT32_MAX); }
@@ -132,9 +132,9 @@
   */
   uint32_t get_packed_size(const unsigned char *ptr_arg, bool low_byte_first);
 
-  DRIZZLED_API uint32_t get_length(uint32_t row_offset= 0);
-  DRIZZLED_API uint32_t get_length(const unsigned char *ptr, bool low_byte_first);
-  DRIZZLED_API uint32_t get_length(const unsigned char *ptr_arg);
+  DRIZZLED_API uint32_t get_length(uint32_t row_offset= 0) const;
+  DRIZZLED_API uint32_t get_length(const unsigned char *ptr, bool low_byte_first) const;
+  DRIZZLED_API uint32_t get_length(const unsigned char *ptr_arg) const;
   void put_length(unsigned char *pos, uint32_t length);
   inline void get_ptr(unsigned char **str)
     {

=== modified file 'drizzled/field/boolean.cc'
--- drizzled/field/boolean.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/boolean.cc	2011-02-19 01:04:19 +0000
@@ -123,19 +123,19 @@
   res.set_ascii(STRING_WITH_LEN("boolean"));
 }
 
-double Boolean::val_real()
-{
-  ASSERT_COLUMN_MARKED_FOR_READ;
-  return isTrue();
-}
-
-int64_t Boolean::val_int()
-{
-  ASSERT_COLUMN_MARKED_FOR_READ;
-  return isTrue();
-}
-
-String *Boolean::val_str(String *val_buffer, String *)
+double Boolean::val_real() const
+{
+  ASSERT_COLUMN_MARKED_FOR_READ;
+  return isTrue();
+}
+
+int64_t Boolean::val_int() const
+{
+  ASSERT_COLUMN_MARKED_FOR_READ;
+  return isTrue();
+}
+
+String *Boolean::val_str(String *val_buffer, String *) const
 {
   ASSERT_COLUMN_MARKED_FOR_READ;
 
@@ -144,7 +144,7 @@
   return val_buffer;
 }
 
-type::Decimal *Boolean::val_decimal(type::Decimal *dec)
+type::Decimal *Boolean::val_decimal(type::Decimal *dec) const
 {
   if (isTrue())
   {

=== modified file 'drizzled/field/boolean.h'
--- drizzled/field/boolean.h	2011-02-02 20:10:49 +0000
+++ drizzled/field/boolean.h	2011-02-19 01:04:19 +0000
@@ -52,10 +52,10 @@
   int store(int64_t nr, bool unsigned_val);
   int store_decimal(const drizzled::type::Decimal*);
 
-  String *val_str(String*,String *);
-  double val_real();
-  int64_t val_int();
-  type::Decimal *val_decimal(type::Decimal *);
+  String *val_str(String*,String *) const;
+  double val_real() const;
+  int64_t val_int() const;
+  type::Decimal *val_decimal(type::Decimal *) const;
 
   void sql_type(drizzled::String&) const;
 

=== modified file 'drizzled/field/date.cc'
--- drizzled/field/date.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/date.cc	2011-02-20 01:01:53 +0000
@@ -173,12 +173,12 @@
   return error;
 }
 
-double Field_date::val_real(void)
+double Field_date::val_real(void) const
 {
   return (double) Field_date::val_int();
 }
 
-int64_t Field_date::val_int(void)
+int64_t Field_date::val_int(void) const
 {
   uint32_t j;
 
@@ -189,7 +189,7 @@
   return (int64_t) j;
 }
 
-String *Field_date::val_str(String *val_buffer, String *)
+String *Field_date::val_str(String *val_buffer, String *) const
 {
   val_buffer->alloc(field_length);
   val_buffer->length(field_length);
@@ -217,7 +217,7 @@
   return val_buffer;
 }
 
-bool Field_date::get_date(type::Time &ltime, uint32_t fuzzydate)
+bool Field_date::get_date(type::Time &ltime, uint32_t fuzzydate) const
 {
   uint32_t tmp=(uint32_t) uint4korr(ptr);
   ltime.day=		(int) (tmp%100);
@@ -230,7 +230,7 @@
           1 : 0);
 }
 
-bool Field_date::get_time(type::Time &ltime)
+bool Field_date::get_time(type::Time &ltime) const
 {
   return Field_date::get_date(ltime ,0);
 }

=== modified file 'drizzled/field/date.h'
--- drizzled/field/date.h	2011-02-14 22:31:26 +0000
+++ drizzled/field/date.h	2011-02-20 01:01:53 +0000
@@ -66,17 +66,17 @@
   int  store(int64_t nr, bool unsigned_val);
   int store_time(type::Time &ltime, type::timestamp_t type);
   int reset(void) { ptr[0]=ptr[1]=ptr[2]=ptr[3]=0; return 0; }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return 4; }
   void sql_type(String &str) const;
   bool can_be_compared_as_int64_t() const { return true; }
   bool zero_pack() const { return 1; }
-  bool get_date(type::Time &ltime,uint32_t fuzzydate);
-  bool get_time(type::Time &ltime);
+  bool get_date(type::Time &ltime,uint32_t fuzzydate) const;
+  bool get_time(type::Time &ltime) const;
 };
 
 } /* namespace drizzled */

=== modified file 'drizzled/field/datetime.cc'
--- drizzled/field/datetime.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/datetime.cc	2011-02-20 01:01:53 +0000
@@ -158,12 +158,12 @@
   return 0;
 }
 
-double Field_datetime::val_real(void)
+double Field_datetime::val_real(void) const
 {
   return (double) Field_datetime::val_int();
 }
 
-int64_t Field_datetime::val_int(void)
+int64_t Field_datetime::val_int(void) const
 {
   int64_t j;
 
@@ -179,8 +179,7 @@
 }
 
 
-String *Field_datetime::val_str(String *val_buffer,
-				String *)
+String *Field_datetime::val_str(String *val_buffer, String *) const
 {
   val_buffer->alloc(DateTime::MAX_STRING_LENGTH);
   val_buffer->length(DateTime::MAX_STRING_LENGTH);
@@ -217,7 +216,7 @@
   return val_buffer;
 }
 
-bool Field_datetime::get_date(type::Time &ltime, uint32_t fuzzydate)
+bool Field_datetime::get_date(type::Time &ltime, uint32_t fuzzydate) const
 {
   int64_t tmp=Field_datetime::val_int();
   uint32_t part1,part2;
@@ -237,7 +236,7 @@
   return (!(fuzzydate & TIME_FUZZY_DATE) && (!ltime.month || !ltime.day)) ? 1 : 0;
 }
 
-bool Field_datetime::get_time(type::Time &ltime)
+bool Field_datetime::get_time(type::Time &ltime) const
 {
   return Field_datetime::get_date(ltime,0);
 }

=== modified file 'drizzled/field/datetime.h'
--- drizzled/field/datetime.h	2011-02-14 22:31:26 +0000
+++ drizzled/field/datetime.h	2011-02-20 01:01:53 +0000
@@ -69,17 +69,17 @@
     ptr[0]=ptr[1]=ptr[2]=ptr[3]=ptr[4]=ptr[5]=ptr[6]=ptr[7]=0;
     return 0;
   }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return 8; }
   void sql_type(String &str) const;
   bool can_be_compared_as_int64_t() const { return true; }
   bool zero_pack() const { return 1; }
-  bool get_date(type::Time &ltime,uint32_t fuzzydate);
-  bool get_time(type::Time &ltime);
+  bool get_date(type::Time &ltime,uint32_t fuzzydate) const;
+  bool get_time(type::Time &ltime) const;
 };
 
 } /* namespace drizzled */

=== modified file 'drizzled/field/decimal.cc'
--- drizzled/field/decimal.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/decimal.cc	2011-02-19 01:04:19 +0000
@@ -260,7 +260,7 @@
 }
 
 
-double Field_decimal::val_real(void)
+double Field_decimal::val_real(void) const
 {
   double dbl;
   type::Decimal decimal_value;
@@ -273,7 +273,7 @@
 }
 
 
-int64_t Field_decimal::val_int(void)
+int64_t Field_decimal::val_int(void) const
 {
   int64_t i;
   type::Decimal decimal_value;
@@ -286,7 +286,7 @@
 }
 
 
-type::Decimal* Field_decimal::val_decimal(type::Decimal *decimal_value)
+type::Decimal* Field_decimal::val_decimal(type::Decimal *decimal_value) const
 {
   ASSERT_COLUMN_MARKED_FOR_READ;
 
@@ -296,8 +296,7 @@
 }
 
 
-String *Field_decimal::val_str(String *val_buffer,
-                               String *)
+String *Field_decimal::val_str(String *val_buffer, String *) const
 {
   type::Decimal decimal_value;
 

=== modified file 'drizzled/field/decimal.h'
--- drizzled/field/decimal.h	2011-02-03 06:31:52 +0000
+++ drizzled/field/decimal.h	2011-02-19 01:04:19 +0000
@@ -70,10 +70,10 @@
   int  store(int64_t nr, bool unsigned_val);
   int store_time(type::Time &ltime, type::timestamp_t t_type);
   int  store_decimal(const type::Decimal *);
-  double val_real(void);
-  int64_t val_int(void);
-  type::Decimal *val_decimal(type::Decimal *);
-  String *val_str(String*, String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  type::Decimal *val_decimal(type::Decimal *) const;
+  String *val_str(String*, String *) const;
   int cmp(const unsigned char *, const unsigned char *);
   void sort_string(unsigned char *buff, uint32_t length);
   bool zero_pack() const { return 0; }

=== modified file 'drizzled/field/double.cc'
--- drizzled/field/double.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/double.cc	2011-02-19 01:04:19 +0000
@@ -84,7 +84,7 @@
                              (double) nr);
 }
 
-double Field_double::val_real(void)
+double Field_double::val_real(void) const
 {
   double j;
 
@@ -101,7 +101,7 @@
   return j;
 }
 
-int64_t Field_double::val_int(void)
+int64_t Field_double::val_int(void) const
 {
   double j;
   int64_t res;
@@ -144,8 +144,7 @@
 }
 
 
-String *Field_double::val_str(String *val_buffer,
-			      String *)
+String *Field_double::val_str(String *val_buffer, String *) const
 {
   double nr;
 

=== modified file 'drizzled/field/double.h'
--- drizzled/field/double.h	2010-02-26 08:21:58 +0000
+++ drizzled/field/double.h	2011-02-19 01:04:19 +0000
@@ -59,9 +59,9 @@
   int  store(double nr);
   int  store(int64_t nr, bool unsigned_val);
   int reset(void) { memset(ptr, 0, sizeof(double)); return 0; }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return sizeof(double); }

=== modified file 'drizzled/field/enum.cc'
--- drizzled/field/enum.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/enum.cc	2011-02-19 01:04:19 +0000
@@ -121,12 +121,12 @@
   return 0;
 }
 
-double Field_enum::val_real(void)
+double Field_enum::val_real(void) const
 {
   return (double) Field_enum::val_int();
 }
 
-int64_t Field_enum::val_int(void)
+int64_t Field_enum::val_int(void) const
 {
   ASSERT_COLUMN_MARKED_FOR_READ;
 
@@ -140,7 +140,7 @@
   return ((int64_t) tmp) + 1; /* SQL is from 1, we store from 0 */
 }
 
-String *Field_enum::val_str(String *, String *val_ptr)
+String *Field_enum::val_str(String *, String *val_ptr) const
 {
   uint32_t tmp=(uint32_t) Field_enum::val_int();
 

=== modified file 'drizzled/field/enum.h'
--- drizzled/field/enum.h	2011-02-17 00:14:13 +0000
+++ drizzled/field/enum.h	2011-02-19 01:04:19 +0000
@@ -61,9 +61,9 @@
   int  store(const char *to, uint32_t length, const CHARSET_INFO * const);
   int  store(double nr);
   int  store(int64_t nr, bool unsigned_val);
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*, String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*, String *) const;
   int cmp(const unsigned char *, const unsigned char *);
   void sort_string(unsigned char *buff, uint32_t length);
   void store_type(uint64_t value);

=== modified file 'drizzled/field/epoch.cc'
--- drizzled/field/epoch.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/epoch.cc	2011-02-20 01:01:53 +0000
@@ -236,12 +236,12 @@
   return 0;
 }
 
-double Epoch::val_real(void)
+double Epoch::val_real(void) const
 {
   return (double) Epoch::val_int();
 }
 
-int64_t Epoch::val_int(void)
+int64_t Epoch::val_int(void) const
 {
   uint64_t temp;
 
@@ -258,7 +258,7 @@
   return result;
 }
 
-String *Epoch::val_str(String *val_buffer, String *)
+String *Epoch::val_str(String *val_buffer, String *) const
 {
   uint64_t temp= 0;
   char *to;
@@ -282,7 +282,7 @@
   return val_buffer;
 }
 
-bool Epoch::get_date(type::Time &ltime, uint32_t)
+bool Epoch::get_date(type::Time &ltime, uint32_t) const
 {
   uint64_t temp;
   type::Time::epoch_t time_temp;
@@ -297,7 +297,7 @@
   return 0;
 }
 
-bool Epoch::get_time(type::Time &ltime)
+bool Epoch::get_time(type::Time &ltime) const
 {
   return Epoch::get_date(ltime, 0);
 }
@@ -368,7 +368,7 @@
   }
 }
 
-long Epoch::get_timestamp(bool *null_value)
+long Epoch::get_timestamp(bool *null_value) const
 {
   if ((*null_value= is_null()))
     return 0;

=== modified file 'drizzled/field/epoch.h'
--- drizzled/field/epoch.h	2011-01-25 05:20:15 +0000
+++ drizzled/field/epoch.h	2011-02-20 01:01:53 +0000
@@ -58,9 +58,9 @@
   int store_decimal(const type::Decimal *value);
 
   int  reset(void) { ptr[0]=ptr[1]=ptr[2]=ptr[3]=ptr[4]=ptr[5]=ptr[6]=ptr[7]=0; return 0; }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return 8; }
@@ -71,7 +71,7 @@
   virtual void set_default();
 
   /* Get TIMESTAMP field value as seconds since begging of Unix Epoch */
-  virtual long get_timestamp(bool *null_value);
+  virtual long get_timestamp(bool *null_value) const;
 
   virtual bool is_timestamp() const
   {
@@ -79,8 +79,8 @@
   }
 
 private:
-  bool get_date(type::Time &ltime,uint32_t fuzzydate);
-  bool get_time(type::Time &ltime);
+  bool get_date(type::Time &ltime,uint32_t fuzzydate) const;
+  bool get_time(type::Time &ltime) const;
 
 public:
   virtual timestamp_auto_set_type get_auto_set_type() const;

=== modified file 'drizzled/field/int32.cc'
--- drizzled/field/int32.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/int32.cc	2011-02-19 01:04:19 +0000
@@ -121,7 +121,7 @@
   }
 
 
-  double Int32::val_real(void)
+  double Int32::val_real(void) const
   {
     int32_t j;
 
@@ -132,7 +132,7 @@
     return (double) j;
   }
 
-  int64_t Int32::val_int(void)
+  int64_t Int32::val_int(void) const
   {
     int32_t j;
 
@@ -143,7 +143,7 @@
     return (int64_t) j;
   }
 
-  String *Int32::val_str(String *val_buffer, String *)
+  String *Int32::val_str(String *val_buffer, String *) const
   {
     const CHARSET_INFO * const cs= &my_charset_bin;
     uint32_t length;

=== modified file 'drizzled/field/int32.h'
--- drizzled/field/int32.h	2010-12-18 00:43:02 +0000
+++ drizzled/field/int32.h	2011-02-19 01:04:19 +0000
@@ -62,9 +62,9 @@
   int store(double nr);
   int store(int64_t nr, bool unsigned_val);
   int reset(void) { ptr[0]=ptr[1]=ptr[2]=ptr[3]=0; return 0; }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return 4; }

=== modified file 'drizzled/field/int64.cc'
--- drizzled/field/int64.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/int64.cc	2011-02-19 01:04:19 +0000
@@ -121,7 +121,7 @@
 }
 
 
-double Int64::val_real(void)
+double Int64::val_real(void) const
 {
   int64_t j;
 
@@ -134,7 +134,7 @@
 }
 
 
-int64_t Int64::val_int(void)
+int64_t Int64::val_int(void) const
 {
   int64_t j;
 
@@ -146,7 +146,7 @@
 }
 
 
-String *Int64::val_str(String *val_buffer, String *)
+String *Int64::val_str(String *val_buffer, String *) const
 {
   const CHARSET_INFO * const cs= &my_charset_bin;
   uint32_t length;

=== modified file 'drizzled/field/int64.h'
--- drizzled/field/int64.h	2011-02-14 22:31:26 +0000
+++ drizzled/field/int64.h	2011-02-19 01:04:19 +0000
@@ -80,9 +80,9 @@
     ptr[0]=ptr[1]=ptr[2]=ptr[3]=ptr[4]=ptr[5]=ptr[6]=ptr[7]=0;
     return 0;
   }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return 8; }

=== modified file 'drizzled/field/microtime.cc'
--- drizzled/field/microtime.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/microtime.cc	2011-02-20 01:01:53 +0000
@@ -158,7 +158,7 @@
   return 0;
 }
 
-double Microtime::val_real(void)
+double Microtime::val_real(void) const
 {
   uint64_t temp;
   type::Time::usec_t micro_temp;
@@ -180,7 +180,7 @@
   return result;
 }
 
-type::Decimal *Microtime::val_decimal(type::Decimal *decimal_value)
+type::Decimal *Microtime::val_decimal(type::Decimal *decimal_value) const
 {
   type::Time ltime;
 
@@ -189,7 +189,7 @@
   return date2_class_decimal(&ltime, decimal_value);
 }
 
-int64_t Microtime::val_int(void)
+int64_t Microtime::val_int(void) const
 {
   uint64_t temp;
 
@@ -207,7 +207,7 @@
   return result;
 }
 
-String *Microtime::val_str(String *val_buffer, String *)
+String *Microtime::val_str(String *val_buffer, String *) const
 {
   uint64_t temp= 0;
   type::Time::usec_t micro_temp= 0;
@@ -224,7 +224,7 @@
   return val_buffer;
 }
 
-bool Microtime::get_date(type::Time &ltime, uint32_t)
+bool Microtime::get_date(type::Time &ltime, uint32_t) const
 {
   uint64_t temp;
   uint32_t micro_temp= 0;
@@ -239,7 +239,7 @@
   return false;
 }
 
-bool Microtime::get_time(type::Time &ltime)
+bool Microtime::get_time(type::Time &ltime) const
 {
   return Microtime::get_date(ltime, 0);
 }
@@ -294,7 +294,7 @@
   pack_num(fractional_seconds, ptr +8);
 }
 
-long Microtime::get_timestamp(bool *null_value)
+long Microtime::get_timestamp(bool *null_value) const
 {
   if ((*null_value= is_null()))
     return 0;

=== modified file 'drizzled/field/microtime.h'
--- drizzled/field/microtime.h	2011-01-25 05:20:15 +0000
+++ drizzled/field/microtime.h	2011-02-20 01:01:53 +0000
@@ -56,10 +56,10 @@
   int store(int64_t nr, bool unsigned_val);
   int store_time(type::Time &ltime, type::timestamp_t t_type);
 
-  String *val_str(String*,String *);
-  double val_real(void);
-  int64_t val_int(void);
-  type::Decimal *val_decimal(type::Decimal *decimal_value);
+  String *val_str(String*,String *) const;
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  type::Decimal *val_decimal(type::Decimal *decimal_value) const;
 
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
@@ -70,11 +70,11 @@
   void set_time();
 
   /* Get TIMESTAMP field value as seconds since begging of Unix Microtime */
-  long get_timestamp(bool *null_value);
+  long get_timestamp(bool *null_value) const;
 
 private:
-  bool get_date(type::Time &ltime,uint32_t fuzzydate);
-  bool get_time(type::Time &ltime);
+  bool get_date(type::Time &ltime,uint32_t fuzzydate) const;
+  bool get_time(type::Time &ltime) const;
 
 public:
   static size_t max_string_length()

=== modified file 'drizzled/field/null.h'
--- drizzled/field/null.h	2011-02-14 22:31:26 +0000
+++ drizzled/field/null.h	2011-02-19 01:04:19 +0000
@@ -79,19 +79,19 @@
   {
     return 0;
   }
-  double val_real(void)
+  double val_real(void) const
   {
     return 0.0;
   }
-  int64_t val_int(void)
-  {
-    return 0;
-  }
-  type::Decimal *val_decimal(type::Decimal *)
-  {
-    return 0;
-  }
-  String *val_str(String *, String *value2)
+  int64_t val_int(void) const
+  {
+    return 0;
+  }
+  type::Decimal *val_decimal(type::Decimal *) const
+  {
+    return 0;
+  }
+  String *val_str(String *, String *value2) const
   {
     value2->length(0);
     return value2;

=== modified file 'drizzled/field/num.cc'
--- drizzled/field/num.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/num.cc	2011-02-19 01:04:19 +0000
@@ -189,7 +189,7 @@
     pointer to decimal buffer with value of field
 */
 
-type::Decimal* Field_num::val_decimal(type::Decimal *decimal_value)
+type::Decimal* Field_num::val_decimal(type::Decimal *decimal_value) const
 {
   assert(result_type() == INT_RESULT);
 

=== modified file 'drizzled/field/num.h'
--- drizzled/field/num.h	2011-02-17 00:14:13 +0000
+++ drizzled/field/num.h	2011-02-19 01:04:19 +0000
@@ -52,7 +52,7 @@
 
   int store_decimal(const type::Decimal *);
 
-  type::Decimal *val_decimal(type::Decimal *);
+  type::Decimal *val_decimal(type::Decimal *) const;
 
   uint32_t is_equal(CreateField *new_field);
 

=== modified file 'drizzled/field/real.cc'
--- drizzled/field/real.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/real.cc	2011-02-19 01:04:19 +0000
@@ -136,7 +136,7 @@
   return store(dbl);
 }
 
-type::Decimal *Field_real::val_decimal(type::Decimal *decimal_value)
+type::Decimal *Field_real::val_decimal(type::Decimal *decimal_value) const
 {
   ASSERT_COLUMN_MARKED_FOR_READ;
 

=== modified file 'drizzled/field/real.h'
--- drizzled/field/real.h	2010-12-25 01:27:46 +0000
+++ drizzled/field/real.h	2011-02-19 01:04:19 +0000
@@ -43,7 +43,7 @@
     not_fixed(dec_arg >= NOT_FIXED_DEC)
     {}
   int store_decimal(const type::Decimal *);
-  type::Decimal *val_decimal(type::Decimal *);
+  type::Decimal *val_decimal(type::Decimal *) const;
   int truncate(double *nr, double max_length);
   uint32_t max_display_length() { return field_length; }
   uint32_t size_of() const { return sizeof(*this); }

=== modified file 'drizzled/field/size.cc'
--- drizzled/field/size.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/size.cc	2011-02-19 01:04:19 +0000
@@ -157,7 +157,7 @@
 }
 
 
-double Size::val_real(void)
+double Size::val_real(void) const
 {
   int64_t j;
 
@@ -169,7 +169,7 @@
 }
 
 
-int64_t Size::val_int(void)
+int64_t Size::val_int(void) const
 {
   int64_t j;
 
@@ -181,7 +181,7 @@
 }
 
 
-String *Size::val_str(String *val_buffer, String *)
+String *Size::val_str(String *val_buffer, String *) const
 {
   const CHARSET_INFO * const cs= &my_charset_bin;
   uint32_t length;

=== modified file 'drizzled/field/size.h'
--- drizzled/field/size.h	2011-02-14 22:31:26 +0000
+++ drizzled/field/size.h	2011-02-19 01:04:19 +0000
@@ -60,9 +60,9 @@
     ptr[0]=ptr[1]=ptr[2]=ptr[3]=ptr[4]=ptr[5]=ptr[6]=ptr[7]=0;
     return 0;
   }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return 8; }

=== modified file 'drizzled/field/str.cc'
--- drizzled/field/str.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/str.cc	2011-02-19 01:04:19 +0000
@@ -110,7 +110,7 @@
   return store(str.ptr(), str.length(), str.charset());
 }
 
-type::Decimal *Field_str::val_decimal(type::Decimal *decimal_value)
+type::Decimal *Field_str::val_decimal(type::Decimal *decimal_value) const
 {
   int64_t nr= val_int();
   int2_class_decimal(E_DEC_FATAL_ERROR, nr, 0, decimal_value);

=== modified file 'drizzled/field/str.h'
--- drizzled/field/str.h	2011-02-17 00:14:13 +0000
+++ drizzled/field/str.h	2011-02-19 01:04:19 +0000
@@ -65,7 +65,7 @@
   bool binary() const { return field_charset == &my_charset_bin; }
   uint32_t max_display_length() { return field_length; }
   friend class CreateField;
-  type::Decimal *val_decimal(type::Decimal *);
+  type::Decimal *val_decimal(type::Decimal *) const;
   virtual bool str_needs_quotes() { return true; }
   uint32_t max_data_length() const;
 };

=== modified file 'drizzled/field/time.cc'
--- drizzled/field/time.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/time.cc	2011-02-20 01:01:53 +0000
@@ -161,7 +161,7 @@
   memcpy(ptr, &tmp, sizeof(int32_t));
 }
 
-void Time::unpack_time(drizzled::Time &temporal)
+void Time::unpack_time(drizzled::Time &temporal) const
 {
   int32_t tmp;
 
@@ -171,18 +171,18 @@
   temporal.from_int32_t(tmp);
 }
 
-void Time::unpack_time(int32_t &destination, const unsigned char *source)
+void Time::unpack_time(int32_t &destination, const unsigned char *source) const
 {
   memcpy(&destination, source, sizeof(int32_t));
   destination= htonl(destination);
 }
 
-double Time::val_real(void)
+double Time::val_real(void) const
 {
   return (double) Time::val_int();
 }
 
-int64_t Time::val_int(void)
+int64_t Time::val_int(void) const
 {
   ASSERT_COLUMN_MARKED_FOR_READ;
 
@@ -195,7 +195,7 @@
   return result;
 }
 
-String *Time::val_str(String *val_buffer, String *)
+String *Time::val_str(String *val_buffer, String *) const
 {
   char *to;
   int to_len= field_length + 1;
@@ -216,7 +216,7 @@
   return val_buffer;
 }
 
-bool Time::get_date(type::Time &ltime, uint32_t)
+bool Time::get_date(type::Time &ltime, uint32_t) const
 {
   ltime.reset();
 
@@ -234,7 +234,7 @@
   return 0;
 }
 
-bool Time::get_time(type::Time &ltime)
+bool Time::get_time(type::Time &ltime) const
 {
   return Time::get_date(ltime, 0);
 }
@@ -275,7 +275,7 @@
   res.set_ascii(STRING_WITH_LEN("timestamp"));
 }
 
-long Time::get_timestamp(bool *null_value)
+long Time::get_timestamp(bool *null_value) const
 {
   if ((*null_value= is_null()))
     return 0;

=== modified file 'drizzled/field/time.h'
--- drizzled/field/time.h	2011-02-14 22:31:26 +0000
+++ drizzled/field/time.h	2011-02-20 01:01:53 +0000
@@ -53,9 +53,9 @@
   int  store(double nr);
   int  store(int64_t nr, bool unsigned_val);
   int  reset(void) { ptr[0]= ptr[1]= ptr[2]= ptr[3]= 0; return 0; }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return 4; }
@@ -64,17 +64,17 @@
   bool zero_pack() const { return 0; }
 
   /* Get TIME field value as seconds since begging of Unix Epoch */
-  long get_timestamp(bool *null_value);
+  long get_timestamp(bool *null_value) const;
 private:
-  bool get_date(type::Time &ltime,uint32_t fuzzydate);
-  bool get_time(type::Time &ltime);
+  bool get_date(type::Time &ltime, uint32_t fuzzydate) const;
+  bool get_time(type::Time &ltime) const;
 
 public:
   timestamp_auto_set_type get_auto_set_type() const;
   static size_t max_string_length();
   void pack_time(drizzled::Time &arg);
-  void unpack_time(drizzled::Time &arg);
-  void unpack_time(int32_t &destination, const unsigned char *source);
+  void unpack_time(drizzled::Time &arg) const;
+  void unpack_time(int32_t &destination, const unsigned char *source) const;
 };
 
 } /* namespace field */

=== modified file 'drizzled/field/uuid.cc'
--- drizzled/field/uuid.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/uuid.cc	2011-02-20 01:01:53 +0000
@@ -103,14 +103,14 @@
   res.set_ascii(STRING_WITH_LEN("uuid"));
 }
 
-double Uuid::val_real()
+double Uuid::val_real() const
 {
   ASSERT_COLUMN_MARKED_FOR_READ;
   my_error(ER_INVALID_UUID_VALUE, MYF(ME_FATALERROR));
   return 0;
 }
 
-int64_t Uuid::val_int()
+int64_t Uuid::val_int() const
 {
   ASSERT_COLUMN_MARKED_FOR_READ;
   my_error(ER_INVALID_UUID_VALUE, MYF(ME_FATALERROR));
@@ -133,7 +133,7 @@
 }
 #endif
 
-String *Uuid::val_str(String *val_buffer, String *)
+String *Uuid::val_str(String *val_buffer, String *) const
 {
   const CHARSET_INFO * const cs= &my_charset_bin;
   uint32_t mlength= (type::Uuid::DISPLAY_BUFFER_LENGTH) * cs->mbmaxlen;
@@ -158,7 +158,7 @@
   memcpy(to, ptr, length_arg);
 }
 
-bool Uuid::get_date(type::Time &ltime, uint32_t )
+bool Uuid::get_date(type::Time &ltime, uint32_t ) const
 {
   type::Uuid uu;
 
@@ -181,7 +181,7 @@
   return true;
 }
 
-bool Uuid::get_time(type::Time &ltime)
+bool Uuid::get_time(type::Time &ltime) const
 {
   return get_date(ltime, 0);
 }

=== modified file 'drizzled/field/uuid.h'
--- drizzled/field/uuid.h	2011-02-17 00:14:13 +0000
+++ drizzled/field/uuid.h	2011-02-20 01:01:53 +0000
@@ -51,9 +51,9 @@
 
   int store(const char *to, uint32_t length, const CHARSET_INFO * const charset);
   int store(int64_t nr, bool unsigned_val);
-  double val_real();
-  int64_t val_int();
-  String *val_str(String*,String *);
+  double val_real() const;
+  int64_t val_int() const;
+  String *val_str(String*,String *) const;
   void sql_type(drizzled::String&) const;
   int store_decimal(const drizzled::type::Decimal*);
 
@@ -66,8 +66,8 @@
   inline String *val_str(String *str) { return val_str(str, str); }
   uint32_t size_of() const { return sizeof(*this); }
 
-  bool get_date(type::Time &ltime, uint32_t);
-  bool get_time(type::Time &ltime);
+  bool get_date(type::Time &ltime, uint32_t) const;
+  bool get_time(type::Time &ltime) const;
 
 #ifdef NOT_YET
   void generate();

=== modified file 'drizzled/field/varstring.cc'
--- drizzled/field/varstring.cc	2011-02-17 00:14:13 +0000
+++ drizzled/field/varstring.cc	2011-02-19 01:04:19 +0000
@@ -124,7 +124,7 @@
 }
 
 
-double Field_varstring::val_real(void)
+double Field_varstring::val_real(void) const
 {
   int not_used;
   char *end_not_used;
@@ -138,7 +138,7 @@
 }
 
 
-int64_t Field_varstring::val_int(void)
+int64_t Field_varstring::val_int(void) const
 {
   int not_used;
   char *end_not_used;
@@ -152,8 +152,7 @@
                      &end_not_used, &not_used);
 }
 
-String *Field_varstring::val_str(String *,
-				 String *val_ptr)
+String *Field_varstring::val_str(String *, String *val_ptr) const
 {
   uint32_t length=  length_bytes == 1 ? (uint32_t) *ptr : uint2korr(ptr);
 
@@ -165,7 +164,7 @@
 }
 
 
-type::Decimal *Field_varstring::val_decimal(type::Decimal *decimal_value)
+type::Decimal *Field_varstring::val_decimal(type::Decimal *decimal_value) const
 {
   uint32_t length;
 

=== modified file 'drizzled/field/varstring.h'
--- drizzled/field/varstring.h	2010-12-25 01:27:46 +0000
+++ drizzled/field/varstring.h	2011-02-19 01:04:19 +0000
@@ -74,11 +74,11 @@
 
   int  store(int64_t nr, bool unsigned_val);
   int  store(double nr) { return Field_str::store(nr); } /* QQ: To be deleted */
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   inline String *val_str(String *str) { return val_str(str, str); }
-  type::Decimal *val_decimal(type::Decimal *);
+  type::Decimal *val_decimal(type::Decimal *) const;
   int cmp_max(const unsigned char *, const unsigned char *, uint32_t max_length);
   inline  int cmp(const unsigned char *str) { return cmp(ptr,str); }
   int cmp(const unsigned char *a,const unsigned char *b)

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2011-02-17 00:14:13 +0000
+++ drizzled/table.h	2011-02-19 03:00:37 +0000
@@ -499,7 +499,7 @@
   }
 
   /* Both of the below should go away once we can move this bit to the field objects */
-  inline bool isReadSet(uint32_t index)
+  inline bool isReadSet(uint32_t index) const
   {
     return read_set->test(index);
   }

